#!/bin/bash -f

#################################################################################
#              set the compilation environment
#
# This script permits to define all needed environment variables and compilation
# flags
#
# Use: "source HDFCompressor-compil-env.sh" before compilation step
#################################################################################

echo " "
echo "---------------------------------------"
echo "-- HDFCompressor compilation environment --"
echo "---------------------------------------"

# --- Set a Machine Specific Environment --- #
MACHINE_NAME=`uname -n`

#--------------------------------------#
# Compiler flags                       #
#--------------------------------------#
export CXX="g++"
export CXXFLAGS="-O2"
export ARFLAGS="cru"

echo " CXX compiler :" $CXX
echo " CXX flags    :" $CXXFLAGS
echo " AR flags     :" $ARFLAGS

#-------------------------#
# HDF library information #
#-------------------------#
case $MACHINE_NAME in
    "raches" )
        export HDF_INC="-I/usr/local/hdf4/include"
        export HDF_LIBDIR="/usr/local/hdf4/lib"
        ;;
    "icarabosse.icare.univ-lille1.fr" )
        export HDF_INC="-I/usr/lib/hdf/include"
        export HDF_LIBDIR="/usr/lib/hdf/lib"
        ;;
    "access.icare.univ-lille1.fr" )
        export HDF_INC="-I/usr/local/hdf4.2r1/include"
        export HDF_LIBDIR="/usr/local/hdf4.2r1/lib"
        ;;
    "camelot.ipsl.polytechnique.fr" )
        export HDF_INC="-I/usr/include/hdf"
        export HDF_LIBDIR="/usr/lib64/hdf"
        ;;
    "loholt1.ipsl.polytechnique.fr" )
        export HDF_INC="-I/usr/include/hdf"
        export HDF_LIBDIR="/usr/lib64/hdf"
        ;;
    "loholt2.ipsl.polytechnique.fr" )
        export HDF_INC="-I/usr/include/hdf"
        export HDF_LIBDIR="/usr/lib64/hdf"
        ;;
     * )
        export HDF_INC="-I/usr/include/hdf"
        export HDF_LIBDIR="/usr/lib/hdf"
        ;;
esac
export HDF_LIBS="-lmfhdf -ldf -ljpeg -lz -lm"

echo " HDF includes      :" $HDF_INC
echo " HDF libs dir      :" $HDF_LIBDIR
echo " HDF libs          :" $HDF_LIBS

echo " "
